/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.parameterized;

/**
 * This interface can be provided in lieu of an object in parameter sets.  This is generally used when the parameter
 * needs to be generated at test time, or generated anew for each test.  The {@link #getType} method is used to
 * check for proper type of the parameters in the method, so it should return the same or a subtype of the parameter
 * required by the method.  The instantiation of the test class will be passed in to {@link #generate} just before the
 * method is invoked (after all befores have been invoked).

 * @author jbunting

 * @param <P> the parameter type
 * @param <TC> the test class type
 */
public interface ParameterSource<P, TC> {

  /**
   * The class of the generated parameter.
   * @return the parameter type
   */
  public Class<? extends P> getType();

  /**
   * Generate the parameter, given the test object.
   * @param testObject the test object
   * @return the generated parameter
   */
  public P generate(TC testObject);
}
