/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.parameterized;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;

/**
 * Indicates that a test method requires a parameter set when run.  The method must still be annotated with
 * {@link org.junit.Test}.
 *
 * @author jbunting
 */

@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
@Inherited
public @interface Parameterized {

  String SINGLETON_NAME = "";

  /**
   * The name of the parameter sets to use.  If no name is specified, then it is expected that the test class defines
   * only one parameter set, which will be used.  If no name is specified and the class defines more than one parameter
   * set, the test will fail validation.
   *
   * @return the name of the parameter set
   */
  public String value() default SINGLETON_NAME;
}
