/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.parameterized.set;

import org.apache.commons.collections15.Transformer;
import org.xj4.parameterized.ParameterSet;

/**
 * An abstract implementation of a parameter set based on the combination of other parameter sets.
 *
 * @author jbunting
 */
public abstract class AbstractCombinedParameterSet extends AbstractParameterSet {
  private ParameterSet[] subSets;

  public AbstractCombinedParameterSet(String name, String[] labelArray, ParameterSet... subSets) {
    super(name, labelArray);
    this.subSets = subSets;
  }

  protected String defaultLabel(final int iteration) {
    return buildDefaultLabel(new Transformer<Integer, String>() {
      public String transform(Integer index) {
        return getSubDefinitions()[index].getIterationLabel(getSubDefinitionIteration(iteration, index));
      }
    });
  }

  protected String defaultName() {
    return buildDefaultLabel(new Transformer<Integer, String>() {
      public String transform(Integer index) {
        return getSubDefinitions()[index].getName();
      }
    });
  }

  protected abstract int getSubDefinitionIteration(int iteration, int subDefinitionIndex);

  protected abstract String getLabelSeparator();

  protected ParameterSet[] getSubDefinitions() {
    return subSets;
  }

  public Object[] getIteration(int iteration) {
    Object[] resultant = new Object[getIterationSize()];
    int copyStart = 0;
    for(int i = 0; i < getSubDefinitions().length; i++) {
      Object[] subIteration = getSubDefinitions()[i].getIteration(getSubDefinitionIteration(iteration, i));
      System.arraycopy(subIteration, 0, resultant, copyStart, subIteration.length);
      copyStart += subIteration.length;
    }
    return resultant;
  }

  protected String buildDefaultLabel(Transformer<Integer, String> subDefinitionLabelRetriever) {
    StringBuilder nameBuilder = new StringBuilder();
    String format = "(%s)";
    nameBuilder.append(String.format(format, subDefinitionLabelRetriever.transform(0)));
    for(int i = 1; i < getSubDefinitions().length; i++) {
      nameBuilder.append(getLabelSeparator());
      nameBuilder.append(String.format(format, subDefinitionLabelRetriever.transform(i)));
    }
    return nameBuilder.toString();
  }

}
