/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.parameterized.set;

import org.apache.commons.lang.NullArgumentException;

/**
 * Abstract implementation of a parameter set based simply on arrays of objects.
 *
 * @author Jared Bunting
 */
public abstract class AbstractSimpleParameterSet<T> extends AbstractParameterSet {

  private T[] iterationArray;

  public AbstractSimpleParameterSet(String name, String[] definedLabels, T[] iterationArray) {
    super(name, definedLabels);
    this.iterationArray = iterationArray;
  }

  /**
   * The default label is simply the iteration index.
   * @param iteration the iteration to specify the label for
   * @return the index
   */
  protected String defaultLabel(int iteration) {
    return Integer.toString(iteration);
  }

  /**
   * The default name is <code>null</code>.
   * @return <code>null</code> as the default name
   */
  protected String defaultName() {
    return null;
  }

  public int getNumIterations() {
    return iterationArray.length;
  }

  protected T[] getIterationArray() {
    return iterationArray;
  }

  public void validate() {
    for(T iteration : iterationArray) {
      if(iteration == null) {
        throw new NullArgumentException("Iteration cannot be null!");
      }
    }
  }
}
