/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.parameterized.set;

import org.apache.commons.lang.NullArgumentException;
import org.xj4.parameterized.ParameterSet;

/**
 * A parameter set that has the same number of iterations as the subset, and one parameter - the index of the iteration.
 * If a parameter set has x parameters and i iterations, the resulting index parameter set will have 1 parameter, i
 * iterations, and will be: [1, 2, ..., i]
 * @author jbunting
 */
public class IndexParameterSet extends AbstractParameterSet {

  private ParameterSet subSet;

  public IndexParameterSet(ParameterSet subSet) {
    this(null, null, subSet);
  }

  public IndexParameterSet(String name, String[] labelArray, ParameterSet subSet) {
    super(name, labelArray);
    this.subSet = subSet;
  }

  public int getNumIterations() {
    return subSet.getNumIterations();
  }

  public Object[] getIteration(int iteration) {
    return new Object[] { iteration };
  }

  protected String defaultLabel(int iteration) {
    return String.format("(%s)#", subSet.getIterationLabel(iteration));
  }

  protected String defaultName() {
    return subSet.getName() + "#";
  }

  public int getIterationSize() {
    return 1;
  }

  public void validate() {
    if(subSet == null) {
      throw new NullArgumentException("SubDefinition cannot be null!");
    }
  }
}
