/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.parameterized.set;

/**
 * A simple parameter set that has more than one parameter.
 *
 * @author jbunting
 */
public class MultiValueParameterSet extends AbstractSimpleParameterSet<Object[]> {

  public MultiValueParameterSet(String[] definedLabels, Object[][] iterationArray) {
    super(null, definedLabels, iterationArray);
  }
  public MultiValueParameterSet(String name, String[] definedLabels, Object[][] iterationArray) {
    super(name, definedLabels, iterationArray);
  }

  public int getIterationSize() {
    return getIterationArray()[0].length;
  }

  public Object[] getIteration(int iteration) {
    return getIterationArray()[iteration];
  }

  public void validate() {
    if(getIterationArray().length > 0) {
      int seedSize = getIterationArray()[0].length;
      for(int i = 1; i < getIterationArray().length; i++) {
        if(getIterationArray()[i].length != seedSize) {
          throw new IllegalArgumentException("All iterations must have the same number of values!");
        }
      }
    }
  }
}
